@@ -7,7 +7,7 @@ def configure_sessions(retries, backoff):
     retry_strategy = Retry(
         total=retries,
         backoff_factor=backoff,
-        status_forcelist=[404]
+        status_forcelist=[404, 403]
     )
     adapter = HTTPAdapter(max_retries=retry_strategy)
     http = requests.Session()
@@ -20,7 +20,7 @@ class Api:
     """
     Base class to inherit requests configuration from
     """
-    http = configure_sessions(8, 1)
+    http = configure_sessions(12, 1)
 
     @classmethod
     def set_timeout(cls, retries, backoff_factor):
